# Note - push to core and tainted

%global pixbuf_moduledir	%(pkg-config gdk-pixbuf-2.0 --variable=gdk_pixbuf_moduledir)

%define         major      1
%define         libname    %mklibname heif %{major}
%define         pluginname %mklibname heif-plugins
%define         devname    %mklibname heif -d


#define         extra 20190816_gite6ecace

%define build_x265 0
%if "%distro_section" == "tainted"
%global build_x265 1
%endif

%define         rel 1

Name:           libheif
Version:        1.19.8
Release:        %mkrel %{?extra:0.%{extra}.}%{rel}
Summary:        libheif is a ISO/IEC 23008-12:2017 HEIF file format decoder and encoder
Group:          System/Libraries
License:        LGPLv2 and GPLv2
URL:            https://www.libheif.org/
%if 0%{?extra}
Source0:        https://github.com/strukturag/libheif/archive/master/%{name}-%{version}%{?extra:-%{extra}}.tar.gz
%define dldir master
%else
Source0:        https://github.com/strukturag/libheif/releases/download/v%{version}/%{name}-%{version}.tar.gz
%define dldir %{version}
%endif

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(libde265)
%if %{build_x265}
BuildRequires:  pkgconfig(x265)
%endif
Requires:       libde265
BuildRequires:  pkgconfig(aom)
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(kvazaar)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(rav1e)
BuildRequires:  pkgconfig(SvtAv1Enc)
BuildRequires:  doxygen
BuildRequires:  ffmpeg-devel

%description
Libheif is an ISO/IEC 23008-12:2017 HEIF file format decoder and encoder.

HEIF is a new image file format that can potentially employ HEVC
(h.265) image coding for efficient compression ratios, but not
only. Alternative codecs for, e.g., AVC and JPEG, PNG can be used.

%if %{build_x265}
Because libheif makes use of libde265 for the actual image decoding
and x265 for encoding, the version using these codecs is impaired by
patents and is in the tainted repository.
%endif

%package        -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       heif-devel = %{version}-%{release}

%description    -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%package        -n %{libname}
Summary:        Shared libraries for %{name}
Group:          System/Libraries
Recommends:     %{name}-plugins%{?_isa} >= %{version}-%{release}
Requires:       heif-pixbuf-loader%{?_isa} >= %{version}-%{release}

%description    -n %{libname}
Shared libraries for %{name}.

%package        -n heif-pixbuf-loader
Summary:        HEIF image loader for GTK+ applications
Group:          Development/Tools
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
Requires:       gdk-pixbuf2.0

Conflicts:      libheif < 1.17.6-4
Conflicts:      %{_lib}heif1 < 1.17.6-4

%description -n	heif-pixbuf-loader
Heif-pixbuf-loader contains a plugin to load HEIF images in GTK+ applications.

%package -n %{pluginname}
Summary:        Codec plugins for %{name}
Group:          System/Libraries
Provides:       %{name}-plugins%{?_isa} = %{version}-%{release}
Provides:       %{name}-plugins = %{version}-%{release}
Conflicts:      %{_lib}heif1 < 1.19.5-5

%description -n %{pluginname}
Codec backend plugins for %{name}.

%prep
%autosetup -n %{name}-%{dldir} -p1

%build
%cmake -GNinja \
       -DCMAKE_COMPILE_WARNING_AS_ERROR=OFF \
       -DENABLE_PLUGIN_LOADING=ON \
       -DWITH_AOM_DECODER=ON \
       -DWITH_AOM_DECODER_PLUGIN=OFF \
       -DWITH_AOM_ENCODER=ON \
       -DWITH_AOM_ENCODER_PLUGIN=OFF \
       -DWITH_DAV1D=ON \
       -DWITH_DAV1D_PLUGIN=ON \
       -DWITH_LIBDE265=ON \
       -DWITH_LIBDE265_PLUGIN=OFF \
       -DWITH_RAV1E=ON \
       -DWITH_RAV1E_PLUGIN=ON \
       -DWITH_SvtEnc=ON \
       -DWITH_SvtEnc_PLUGIN=ON \
%if 0%{?build_x265}
       -DWITH_X265=ON \
       -DWITH_X265_PLUGIN=OFF \
%else
       -DWITH_X265=OFF \
       -DWITH_X265_PLUGIN=OFF \
%endif
       -DWITH_JPEG_DECODER=ON \
       -DWITH_JPEG_DECODER_PLUGIN=ON \
       -DWITH_JPEG_ENCODER=ON \
       -DWITH_JPEG_ENCODER_PLUGIN=ON \
       -DWITH_UNCOMPRESSED_CODEC=ON \
       -DWITH_KVAZAAR=ON \
%if 0%{?build_x265}
       -DWITH_KVAZAAR_PLUGIN=ON \
%else
       -DWITH_KVAZAAR_PLUGIN=OFF \
%endif
       -DWITH_OpenJPEG_DECODER=ON \
       -DWITH_OpenJPEG_DECODER_PLUGIN=ON \
       -DWITH_OpenJPEG_ENCODER=ON \
       -DWITH_OpenJPEG_ENCODER_PLUGIN=ON \
       -DWITH_OPENJPH_ENCODER=OFF \
       -DWITH_FFMPEG_DECODER=ON \
       -DWITH_FFMPEG_DECODER_PLUGIN=ON \
       -DWITH_OpenH264_DECODER=OFF \
       -DWITH_OpenH264_DECODER_PLUGIN=OFF \
       -DWITH_UVG266=OFF \
       -DWITH_UVG266_PLUGIN=OFF \
       -DWITH_VVDEC=OFF \
       -DWITH_VVDEC_PLUGIN=OFF \
       -DWITH_VVENC=OFF \
       -DWITH_VVENC_PLUGIN=OFF
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license COPYING
%{_bindir}/heif*
%{_mandir}/man1/heif*

%files -n %{libname}
%license COPYING
%dir %{_libdir}/%{name}
%{_libdir}/%{name}.so.%{major}
%{_libdir}/%{name}.so.%{version}

%files -n %{pluginname}
%{_libdir}/%{name}/libheif-dav1d.so
%{_libdir}/%{name}/libheif-ffmpegdec.so
%{_libdir}/%{name}/libheif-jpegdec.so
%{_libdir}/%{name}/libheif-jpegenc.so
%{_libdir}/%{name}/libheif-j2kdec.so
%{_libdir}/%{name}/libheif-j2kenc.so
%if 0%{?build_x265}
%{_libdir}/%{name}/libheif-kvazaar.so
%endif
%{_libdir}/%{name}/libheif-rav1e.so
%{_libdir}/%{name}/libheif-svtenc.so

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/*%{name}*.so
%{_libdir}/pkgconfig/libheif.pc
%{_libdir}/cmake/libheif/

%files -n heif-pixbuf-loader
%license COPYING
%{pixbuf_moduledir}/libpixbufloader-heif.so
%{_datadir}/thumbnailers/heif.thumbnailer


%changelog
* Fri Jun 20 2025 wally <wally> 1.19.8-1.mga10
+ Revision: 2193036
- new version 1.19.8

* Wed Mar 12 2025 daviddavid <daviddavid> 1.19.7-1.mga10
+ Revision: 2162952
- new version: 1.19.7

* Sat Dec 14 2024 wally <wally> 1.19.5-6.mga10.tainted
+ Revision: 2124988
- remove unneeded example program requires from lib pkg

* Fri Dec 13 2024 wally <wally> 1.19.5-5.mga10.tainted
+ Revision: 2124753
- build only minimal HEIC and AVIF support as built-in
- build other codec backends as dynamic plugins
- split out dynamic plugins from lib pkg
- recommend dynamic plugins pkg

* Wed Dec 11 2024 daviddavid <daviddavid> 1.19.5-4.mga10.tainted
+ Revision: 2123604
- enable ffmpegdec plugin
- really enable kvazaar support

* Wed Dec 11 2024 daviddavid <daviddavid> 1.19.5-3.mga10
+ Revision: 2123541
- rebuild for new x265 4.1
- enable kvazaar support

* Wed Dec 11 2024 daviddavid <daviddavid> 1.19.5-2.mga10
+ Revision: 2123425
- new version: 1.19.5
- enable rav1e support
+ kekepower <kekepower>
- Update to version 1.19.3

* Fri Aug 09 2024 kekepower <kekepower> 1.18.2-1.mga10.tainted
+ Revision: 2084325
- Update to version 1.18.2

* Tue Jul 23 2024 kekepower <kekepower> 1.18.1-1.mga10
+ Revision: 2082299
- Update to version 1.18.1

* Thu Jul 11 2024 kekepower <kekepower> 1.18.0-1.mga10.tainted
+ Revision: 2080656
- Update to version 1.18.0

* Thu Apr 25 2024 daviddavid <daviddavid> 1.17.6-5.mga10.tainted
+ Revision: 2061038
- rebuild for missing pkgs

* Thu Apr 25 2024 daviddavid <daviddavid> 1.17.6-4.mga10
+ Revision: 2061016
- split out in a separate sub-pkg the HEIF image loader plugin

* Thu Apr 25 2024 daviddavid <daviddavid> 1.17.6-3.mga10.tainted
+ Revision: 2061012
- backport upstream patch to fix compilation with libsvtav1 2.0.0
- rebuild for new svt-av1 2.0.0

* Sun Apr 14 2024 daviddavid <daviddavid> 1.17.6-2.mga10.tainted
+ Revision: 2057226
- rebuild for new x265 3.6

* Thu Dec 21 2023 kekepower <kekepower> 1.17.6-1.mga10.tainted
+ Revision: 2020621
- Update to version 1.17.6
- Fixes CVE-2023-49462 and CVE-2023-49463

* Tue Nov 21 2023 kekepower <kekepower> 1.17.5-1.mga10.tainted
+ Revision: 2008807
- Update to version 1.17.5

* Mon Nov 20 2023 kekepower <kekepower> 1.17.4-1.mga10.tainted
+ Revision: 2008521
- Update to version 1.17.4

* Fri Nov 03 2023 kekepower <kekepower> 1.17.3-1.mga10.tainted
+ Revision: 2003846
- Update to version 1.17.3

* Fri Oct 20 2023 kekepower <kekepower> 1.17.1-1.mga10.tainted
+ Revision: 1999783
- Update to version 1.17.1

* Mon Oct 16 2023 kekepower <kekepower> 1.17.0-2.mga10.tainted
+ Revision: 1997202
- Try using OpenJPEG2

* Mon Oct 16 2023 kekepower <kekepower> 1.17.0-1.mga10
+ Revision: 1997154
- Update to version 1.17.0

* Wed May 24 2023 kekepower <kekepower> 1.16.2-1.mga9.tainted
+ Revision: 1957871
- Update to version 1.16.2

* Wed May 03 2023 kekepower <kekepower> 1.16.1-2.mga9.tainted
+ Revision: 1955705
- Add upstream patch to fix build on armv7hl (Thanks tmb)
- Remove subrel

* Wed May 03 2023 kekepower <kekepower> 1.16.1-1.1.mga9.tainted
+ Revision: 1955691
- Update to version 1.16.1

* Fri Mar 31 2023 kekepower <kekepower> 1.15.2-1.mga9.tainted
+ Revision: 1951010
- Update to version 1.15.2

* Sun Mar 12 2023 kekepower <kekepower> 1.15.1-2.mga9
+ Revision: 1948700
- Use libde265 from core as well

* Sun Feb 19 2023 kekepower <kekepower> 1.15.1-1.mga9.tainted
+ Revision: 1944117
- Update to version 1.15.1
+ wally <wally>
- use %%cmake_build and %%cmake_install

* Mon Jan 16 2023 daviddavid <daviddavid> 1.14.2-5.mga9
+ Revision: 1933717
- enable svt-av1 encoder support
- fix owner of cmake config files

* Mon Jan 16 2023 kekepower <kekepower> 1.14.2-4.mga9
+ Revision: 1933708
- Switch to cmake build

* Mon Jan 16 2023 daviddavid <daviddavid> 1.14.2-3.mga9.tainted
+ Revision: 1933687
- enable dav1d support

* Mon Jan 16 2023 daviddavid <daviddavid> 1.14.2-2.mga9.tainted
+ Revision: 1933680
- enable jpeg-xl support

* Sat Jan 07 2023 kekepower <kekepower> 1.14.2-1.mga9.tainted
+ Revision: 1930876
- Update to version 1.14.2

* Tue Jan 03 2023 kekepower <kekepower> 1.14.1-1.mga9.tainted
+ Revision: 1929549
- Update to version 1.14.1

* Wed Nov 16 2022 kekepower <kekepower> 1.14.0-1.mga9
+ Revision: 1907934
+ rebuild (emptylog)

* Wed Nov 16 2022 kekepower <kekepower> 1.14.0-1.mga9.tainted
+ Revision: 1907933
- Update to version 1.14.0

* Sat Sep 03 2022 kekepower <kekepower> 1.13.0-1.mga9
+ Revision: 1883594
- Update to version 1.13.0

* Tue Apr 05 2022 kekepower <kekepower> 1.12.0-5.mga9.tainted
+ Revision: 1844826
- Add upstream patch to fix dav1d decoding: input stream must be flushed with dav1d 1.0.0

* Mon Apr 04 2022 umeabot <umeabot> 1.12.0-4.mga9
+ Revision: 1843698
- Mageia 9 Mass Rebuild

* Tue Mar 29 2022 kekepower <kekepower> 1.12.0-3.mga9.tainted
+ Revision: 1831738
- Rebuild for new dav1d

* Fri Jul 16 2021 luigiwalser <luigiwalser> 1.12.0-2.mga9.tainted
+ Revision: 1736234
- rebuild for aom

* Fri May 07 2021 kekepower <kekepower> 1.12.0-1.mga9.tainted
+ Revision: 1722264
- Update to version 1.12.0

* Thu Feb 25 2021 kekepower <kekepower> 1.11.0-1.mga9.tainted
+ Revision: 1690901
- Update to version 1.11.0

* Thu Dec 17 2020 kekepower <kekepower> 1.10.0-1.mga8.tainted
+ Revision: 1659917
- Update to version 1.10.0

* Fri Sep 25 2020 kekepower <kekepower> 1.9.1-1.mga8.tainted
+ Revision: 1630016
- Update to version 1.9.1

* Mon Aug 31 2020 kekepower <kekepower> 1.8.0-1.mga8
+ Revision: 1620346
- Update to version 1.8.0

* Mon Jul 13 2020 daviddavid <daviddavid> 1.7.0-3.mga8
+ Revision: 1605741
- rebuild for new x265 3.4
+ kekepower <kekepower>
- Rebuild with new aom

* Wed Jun 10 2020 kekepower <kekepower> 1.7.0-1.mga8
+ Revision: 1591823
- Update to version 1.7.0

* Mon May 25 2020 tv <tv> 1.6.2-3.mga8.tainted
+ Revision: 1587548
- rebuild for new x265

* Mon Mar 16 2020 eatdirt <eatdirt> 1.6.2-2.mga8.tainted
+ Revision: 1556740
- Build a free version to core (see #mga26330)

* Fri Feb 21 2020 kekepower <kekepower> 1.6.2-1.mga8.tainted
+ Revision: 1549171
- Update to version 1.6.2
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jan 12 2020 kekepower <kekepower> 1.6.1-1.mga8.tainted
+ Revision: 1477744
- Update to version 1.6.1
+ wally <wally>
- drop unneeded P1

* Fri Nov 08 2019 kekepower <kekepower> 1.6.0-1.mga8.tainted
+ Revision: 1458765
- Update to version 1.6.0

* Sat Oct 19 2019 zezinho <zezinho> 1.5.1-2.mga8.tainted
+ Revision: 1454632
- Rebuild against new x265

* Fri Aug 30 2019 kekepower <kekepower> 1.5.1-1.mga8.tainted
+ Revision: 1435187
- Update to version 1.5.1

* Fri Aug 16 2019 kekepower <kekepower> 1.5.0-1.mga8.tainted
+ Revision: 1429451
- Update to version 1.5.0
- Rebuild for new libx265

* Tue Jul 02 2019 kekepower <kekepower> 1.4.0-3.mga8.tainted
+ Revision: 1417754
- Rebuild with updated libde265

* Sun Apr 14 2019 wally <wally> 1.4.0-2.mga7.tainted
+ Revision: 1390102
- move gdk-pixbuf loader to lib pkg
- add patch to build gdk-pixbuf loader as a module

* Tue Feb 26 2019 kekepower <kekepower> 1.4.0-1.mga7.tainted
+ Revision: 1370266
- Update to version 1.4.0

* Sun Feb 10 2019 kekepower <kekepower> 1.3.2-0.20190206_git9d96532.1.mga7.tainted
+ Revision: 1364856
- Add BuildRequires for gdk-pixbuf
- Update to release 20190206_git9d96532

* Mon Feb 04 2019 zezinho <zezinho> 1.3.2-0.20190131_git75333c2.2.mga7.tainted
+ Revision: 1363061
- rebuild for libx265

* Thu Jan 31 2019 kekepower <kekepower> 1.3.2-0.20190131_git75333c2.1.mga7.tainted
+ Revision: 1362111
- Update to release 20190131_git75333c2

* Fri Dec 14 2018 kekepower <kekepower> 1.3.2-0.20181214_gite20251d.1.mga7.tainted
+ Revision: 1341175
- Update to release 20181214_gite20251d

* Fri Nov 23 2018 kekepower <kekepower> 1.3.2-0.20181121_git791fa2d.1.mga7.tainted
+ Revision: 1333675
- Update to release 20181121_git791fa2d

* Sat Oct 20 2018 daviddavid <daviddavid> 1.3.2-0.20181016_git659fb68.3.mga7.tainted
+ Revision: 1322841
- devel pkg requires main lib pkg
- add some missing Provides and Group

* Tue Oct 16 2018 kekepower <kekepower> 1.3.2-0.20181016_git659fb68.2.mga7.tainted
+ Revision: 1321168
- Fix devel and library packages

* Tue Oct 16 2018 kekepower <kekepower> 1.3.2-0.20181016_git659fb68.1.mga7.tainted
+ Revision: 1320981
- imported package libheif

